@@ -3,27 +3,37 @@ import k3d
 from abc import ABCMeta, abstractmethod
 
 
+def create_line_between_joints(start, end):
+    line = k3d.line(
+            vertices=[start, end],
+            shader='mesh',
+            width=0.1)
+    return line
+
+
 class AbstractJointSet(metaclass=ABCMeta):
+    def __init__(self):
+        self.limb_graph = None
+        self.number_of_joints = None
+
     @abstractmethod
     def convert_to_common_14(self):
         return None
 
     def generate_skeleton_from_coordinates(self, joint_coordinates):
         assert joint_coordinates.shape == (self.number_of_joints, 3)
-        joint_points = k3d.points(positions=joint_coordinates, point_size=0.5, shader='mesh')
-        lines = []
-        for line_indices in self.limb_graph:
-            lines.append(k3d.line(
-                vertices=[
-                    joint_coordinates[line_indices[0]],
-                    joint_coordinates[line_indices[1]]],
-                shader='mesh',
-                width=2.5))
-        return joint_points, lines
+        joint_points = k3d.points(positions=joint_coordinates, point_size=0.4, shader='mesh')
+        lines_between_joint_points = [line for line in map(
+            lambda line_indices: create_line_between_joints(
+                start=joint_coordinates[line_indices[0]],
+                end=joint_coordinates[line_indices[1]]),
+            self.limb_graph)]
+        return joint_points, lines_between_joint_points
 
 
 class MuPoTSJoints(AbstractJointSet):
     def __init__(self):
+        super().__init__()
         self.names = np.array([
             'head_top', 'neck', 'right_shoulder', 'right_elbow',
             'right_wrist', 'left_shoulder', 'left_elbow', 'left_wrist',
@@ -49,6 +59,7 @@ class MuPoTSJoints(AbstractJointSet):
 
 class OpenPoseJoints(AbstractJointSet):
     def __init__(self):
+        super().__init__()
         self.names = np.array([
             'nose', 'neck', 'right_shoulder', 'right_elbow',
             'right_wrist', 'left_shoulder', 'left_elbow', 'left_wrist',
@@ -80,6 +91,7 @@ class OpenPoseJoints(AbstractJointSet):
 
 class CocoExJoints(AbstractJointSet):
     def __init__(self):
+        super().__init__()
         self.names = np.array([
             'nose', 'left_eye', 'right_eye', 'left_ear',
             'right_ear', 'left_shoulder', 'right_shoulder', 'left_elbow',
@@ -107,6 +119,7 @@ class CocoExJoints(AbstractJointSet):
 
 class PanopticJoints(AbstractJointSet):
     def __init__(self):
+        super().__init__()
         self.names = np.array([
             'neck', 'nose', 'hip',
             'left_shoulder', 'left_elbow', 'left_wrist',
@@ -140,6 +153,7 @@ class Common14Joints(AbstractJointSet):
         'left_ankle', 'neck', 'left_shoulder', 'left_elbow',
         'left_wrist', 'right_shoulder', 'right_elbow', 'right_wrist'
     ])):
+        super().__init__()
         self.names = names
         self.number_of_joints = 14
         self.limb_graph = [
